@@ -9,8 +9,6 @@
 
 #include "exslt.h"
 
-/* extern double xmlXPathNAN; */
-
 /**
  * exsltMathMin:
  * @ns:  a node-set
@@ -30,11 +28,11 @@ exsltMathMin (xmlNodeSetPtr ns) {
     if ((ns == NULL) || (ns->nodeNr == 0))
 	return(xmlXPathNAN);
     ret = xmlXPathCastNodeToNumber(ns->nodeTab[0]);
-    if (ret == xmlXPathNAN)
+    if (xmlXPathIsNaN(ret))
 	return(xmlXPathNAN);
     for (i = 1; i < ns->nodeNr; i++) {
 	cur = xmlXPathCastNodeToNumber(ns->nodeTab[i]);
-	if (cur == xmlXPathNAN)
+	if (xmlXPathIsNaN(cur))
 	    return(xmlXPathNAN);
 	if (cur < ret)
 	    ret = cur;
@@ -91,11 +89,11 @@ exsltMathMax (xmlNodeSetPtr ns) {
     if ((ns == NULL) || (ns->nodeNr == 0))
 	return(xmlXPathNAN);
     ret = xmlXPathCastNodeToNumber(ns->nodeTab[0]);
-    if (ret == xmlXPathNAN)
+    if (xmlXPathIsNaN(ret))
 	return(xmlXPathNAN);
     for (i = 1; i < ns->nodeNr; i++) {
 	cur = xmlXPathCastNodeToNumber(ns->nodeTab[i]);
-	if (cur == xmlXPathNAN)
+	if (xmlXPathIsNaN(cur))
 	    return(xmlXPathNAN);
 	if (cur > ret)
 	    ret = cur;
@@ -150,14 +148,14 @@ exsltMathHighest (xmlNodeSetPtr ns) {
 	return(ret);
 
     max = xmlXPathCastNodeToNumber(ns->nodeTab[0]);
-    if (max == xmlXPathNAN)
+    if (xmlXPathIsNaN(max))
 	return(ret);
     else
 	xmlXPathNodeSetAddUnique(ret, ns->nodeTab[0]);
 
     for (i = 1; i < ns->nodeNr; i++) {
 	cur = xmlXPathCastNodeToNumber(ns->nodeTab[i]);
-	if (cur == xmlXPathNAN) {
+	if (xmlXPathIsNaN(cur)) {
 	    xmlXPathEmptyNodeSet(ret);
 	    return(ret);
 	}
@@ -221,14 +219,14 @@ exsltMathLowest (xmlNodeSetPtr ns) {
 	return(ret);
 
     min = xmlXPathCastNodeToNumber(ns->nodeTab[0]);
-    if (min == xmlXPathNAN)
+    if (xmlXPathIsNaN(min))
 	return(ret);
     else
 	xmlXPathNodeSetAddUnique(ret, ns->nodeTab[0]);
 
     for (i = 1; i < ns->nodeNr; i++) {
 	cur = xmlXPathCastNodeToNumber(ns->nodeTab[i]);
-	if (cur == xmlXPathNAN) {
+	if (xmlXPathIsNaN(cur)) {
 	    xmlXPathEmptyNodeSet(ret);
 	    return(ret);
 	}
